<!--
为了方便我们能够复现和修复 bug，请遵从下面的规范描述您的问题。
-->
#### 问题简述 (One-line summary)



#### 版本及环境 (Version & Environment)
+ ECharts 版本 (ECharts version):
+ 浏览器类型和版本 (Browser version):
+ 操作系统类型和版本 (OS Version):


#### 重现步骤 (Steps to reproduce)
1.
2.


#### 期望结果 (Expected behaviour)



#### 可能哪里有问题 (What went wrong)



#### ECharts配置项 (ECharts option)
<!-- 下方贴你的option，注意不要删掉下方 ```javascript 和 尾部的 ``` 字样。
最好是我们能够直接运行的 option。如何得到能运行的 option 参见上方的 guidelines for contributing
-->
```javascript
option = {

}

```


#### 其他信息 (Other comments)
<!-- 例如，截图或线上实例 (JSFiddle/JSBin/Codepen) (For example: Screenshot or Online demo) -->

